"""Top-level package for SMTP-based notification email utils."""

__author__ = """Jaideep Sundaram"""
__email__ = "jai.python3@gmail.com"
__version__ = "0.2.0"

# from .[new_project] import Something as Something
